!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_core
!! NAME
!! calc_core
!!
!! FUNCTION
!! Convert core density and pseudized core densisty
!! from densities read from uspp (divide them by 4Pi.r2)
!!
!! COPYRIGHT
!! Copyright (C) 1998-2007 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawarray
!!    %coreden4pr2(max_meshsz)= Core density multiplied by 4Pi.r2
!!    %tcoreden4pr2(max_meshsz)= Pseudo core density multiplied by 4Pi.r2
!!  pawrad=datastructure containing mesh size definitions
!!  pshead
!!    %atomic_charge= Total atomic charge
!!    %sph_meshsz= Dimension of radial mesh for spheres
!!    %valence_charge= Valence charge
!!  un_log= Unit number for log file (comments)
!!
!! OUTPUT
!!  pawps
!!    %coredens(pshead%core_meshsz) = Core density of the atom
!!    %tcoredens(pshead%core_meshsz)= Pseudo-core density of the atom
!!
!! SIDE EFFECTS
!!  pshead
!!    %core_meshsz= Dimension of radial mesh for core and tcore densities
!!
!! PARENTS
!!      uspp2abinit
!!
!! CHILDREN
!!      deducer0
!!
!! SOURCE

 subroutine calc_core(pawarray,pawrad,pawps,pshead,un_log)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ------------------------------------
 integer :: un_log
 type(pawarray_type) :: pawarray
 type(pawrad_type)   :: pawrad
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables-------------------------------
 real(dp),parameter :: core_prec=1.d-7
 integer :: ir,isize
 real(dp) :: zcore,zcalc

! *************************************************************************

!Evaluate coredens and tcoredens for r>0
 do ir=2,pshead%core_meshsz
  pawps%coredens(ir) = pawarray%coreden4pr2(ir) /(four_pi*pawrad%rad(ir)**2)
  pawps%tcoredens(ir)= pawarray%tcoreden4pr2(ir)/(four_pi*pawrad%rad(ir)**2)
 enddo

!Deduce coredens and tcoredens  at r=0
 call deducer0(pawps%coredens,pawrad)
 call deducer0(pawps%tcoredens,pawrad)

!Adjust mesh size for (t)core density in order to get Zcore lower than given precision
 zcore=pshead%atomic_charge-pshead%valence_charge
 isize=pshead%core_meshsz;zcalc=zcore
 do while (abs(zcalc-zcore)<core_prec.and.isize>1)
  isize=isize-1;call csimp(pawarray%coreden4pr2,pawrad,isize,zcalc)
 enddo
 pshead%core_meshsz=max(min(isize+1,pshead%core_meshsz),pshead%sph_meshsz)
 if (pshead%core_meshsz>pshead%sph_meshsz) then
  write(un_log,'(/,a)') '> USpp->Abinit translator INFO:'
  write(un_log,'(a,i4,/,a,g9.2,a)') &
&   '  Mesh size for core density has been adjusted to ',pshead%core_meshsz,&
&   '  in order to get Zcore lower than given precision (',core_prec,').'
 endif

end subroutine
!!***
