!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_descr
!! NAME
!! calc_descr
!!
!! FUNCTION
!! Compute descreened pseudo-potential
!!
!! COPYRIGHT
!! Copyright (C) 1998-2007 ABINIT group (MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  option= 0 if descreened potential comes directly from USPP
!!          1 if descreened potential is computed here
!!  pawarray
!!    %shpnrm(0)= Norm of compensation density (intg of n-n_tild)
!!    %tvaleden4pr2(max_meshsz)= Pseudo valence density multiplied by 4Pi.r2
!!    %tcoreden4pr2(max_meshsz)= Pseudo core density multiplied by 4Pi.r2
!!  pawrad=datastructure containing mesh size definitions
!!  pshead
!!    %vloc_meshsz= Dimension of radial mesh for vloc=vhtnzc
!!    %wav_meshsz=Mesh size for partial waves and projectors inherited from uspp
!!  un_log= Unit number for log file (comments)
!!  usdata
!!    %exfact= USpp s code number for the exchange-correlation
!!    %rvloc(max_meshsz)= Pseudized potential * r
!!    %rvloc0(max_meshsz)= Descreened pseudized potential * r (from USPP)
!!  usexcnhat=Option governing the use of nhat in XC terms
!!            if option=0 and usexcnhat=0, potential is re-screened and descreened again
!!
!! OUTPUT
!!  pawarray
!!    %rvloc0(max_meshsz)= Descreened pseudized potential * r
!!
!! PARENTS
!!      uspp2abinit
!!
!! CHILDREN
!!      calc_vxc,csimp,poisson
!!
!! SOURCE

 subroutine calc_descr(option,pawarray,pawrad,pshead,un_log,usdata,usexcnhat)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ------------------------------------	
 integer :: option,un_log,usexcnhat
 type(pawarray_type) :: pawarray
 type(pawps_type)    :: pawps
 type(pawrad_type)   :: pawrad
 type(pshead_type)   :: pshead
 type(usdata_type)   :: usdata

!Local variables-------------------------------
 integer :: meshsz,maxmsz
 real(dp), allocatable :: den4pr2(:),hatden4pr2(:),rvh(:),rvxc(:),rvxc_hat(:)

! *************************************************************************

 meshsz=pshead%wav_meshsz
 maxmsz=pshead%max_meshsz

 if (usexcnhat==0) then
  write(un_log,'(/,a)') '> USpp->Abinit translator INFO:'
  write(un_log,'(a)') '  Compensation charge density is not included in XC terms (Blochl s formulation).'
 endif

 if (option==0.and.usexcnhat/=0) then
  pawarray%rvloc0(1:maxmsz)=usdata%rvloc0(1:maxmsz)
  return
 endif

 allocate(den4pr2(maxmsz),hatden4pr2(meshsz),rvh(maxmsz),rvxc(maxmsz))

!Compute "new" hat density
 hatden4pr2(1:meshsz)=pawarray%shpnrm(0)*pawarray%shapefunc(1:meshsz)*pawrad%rad(1:meshsz)**2

!Compute Hartree potential
 den4pr2(1:maxmsz)=pawarray%tvaleden4pr2(1:maxmsz)
 den4pr2(1:meshsz)=den4pr2(1:meshsz)+hatden4pr2(1:meshsz)
 call poisson(den4pr2,maxmsz,pawrad,rvh)

!Compute XC potential
 den4pr2(1:maxmsz)=pawarray%tvaleden4pr2(1:maxmsz)+pawarray%tcoreden4pr2(1:maxmsz)
 if (usexcnhat==0) then
  call calc_vxc(den4pr2,maxmsz,pawrad,rvxc,usdata%exfact,un_log)
 end if
 if (usexcnhat/=0.or.option==0) then
  allocate(rvxc_hat(maxmsz))
  den4pr2(1:maxmsz)=den4pr2(1:maxmsz)+hatden4pr2(1:meshsz)
  call calc_vxc(den4pr2,maxmsz,pawrad,rvxc_hat,usdata%exfact,un_log)
  if (option==0.and.usexcnhat==0) then
   rvxc=rvxc-rvxc_hat
  else
   rvxc=rvxc_hat
  end if
  deallocate(rvxc_hat)
 end if

!Descreen potential
 pawarray%rvloc0(1:maxmsz)=usdata%rvloc(1:maxmsz)-rvh(1:maxmsz)-rvxc(1:maxmsz)

 deallocate(den4pr2,hatden4pr2,rvh,rvxc)

end subroutine
!!***
