!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_rhoij0
!! NAME
!! calc_rhoij0
!! 
!! FUNCTION
!! Compute initial values (atomic initialization) of rhoij0
!!
!! COPYRIGHT
!! Copyright (C) 1998-2007 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  pawarray
!!    %factscale(basis_size)= Scaling factors for Phi, tPhi and tProj
!!    %indlmn(6,lmn_size)= Gives l,m,n,lm,ln,s for i=lmn
!!  pshead
!!    %basis_size= Number of elements for the paw nl basis
!!    %lmn_size= Number of elements for the paw basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!  usdata
!!    %keyee(basis_size)= Indice of reference (eigen)energy for each basis function
!!    %lval(nval)= l angular momentum for each valence state
!!    %nval= Number of valence states
!!    %occ(nval)= Valence states occupancies
!!    %snlprj(basis_size,nval)= Projected eigentstates, i.e. <Snl(j)|Proj(i)> scalars
!!
!! OUTPUT
!!  pawps
!!    %rhoij0= Atomic initialization of rhoij
!!
!! PARENTS
!!      uspp2abinit
!!
!! CHILDREN
!!
!! SOURCE

 subroutine calc_rhoij0(pawarray,pawps,pshead,usdata)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 type(pawarray_type) :: pawarray
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead
 type(usdata_type)   :: usdata

!Local variables ---------------------------------------
 integer :: ib,il,ilmn,ilm,iln,ival,jb,jl,jlm,jln,jlmn,j0lmn,klmn
 real(dp) :: faci,factj
 real(dp), allocatable :: work(:,:)

! *************************************************************************

 allocate(work(pshead%basis_size,pshead%basis_size));work=zero
 do ival=1,usdata%nval
  do jb=1,pshead%basis_size
   if (usdata%lval(ival)==pshead%orbitals(jb)) then
    do ib=1,pshead%basis_size
     if (usdata%lval(ival)==pshead%orbitals(ib)) then
      if ((usdata%keyee(ib)==ival.and.usdata%keyee(jb)==ival).or. &
&         (usdata%keyee(ib)/=ival.and.usdata%keyee(jb)/=ival)) &
&       work(ib,jb)=work(ib,jb)+usdata%occ(ival)*usdata%snlprj(ib,ival)*usdata%snlprj(jb,ival) &
&                              /pawarray%factscale(ib)/pawarray%factscale(jb)
     endif
    enddo
   endif
  enddo
 enddo
 do jb=1,pshead%basis_size
  do ib=1,pshead%basis_size
   if (abs(work(ib,jb)-nint(work(ib,jb)))<tol6) work(ib,jb)=nint(work(ib,jb))
  enddo
 enddo

 pawps%rhoij0=zero
 do jlmn=1,pshead%lmn_size
  j0lmn=jlmn*(jlmn-1)/2
  jl =pawarray%indlmn(1,jlmn)
  jlm=pawarray%indlmn(4,jlmn)
  jln=pawarray%indlmn(5,jlmn)
  do ilmn=1,jlmn
   klmn=j0lmn+ilmn
   il =pawarray%indlmn(1,ilmn)
   ilm=pawarray%indlmn(4,ilmn)
   iln=pawarray%indlmn(5,ilmn)
   if (jl==il.and.ilm==jlm) pawps%rhoij0(klmn)=work(iln,jln)/dble(2*il+1)
  enddo
 enddo

 deallocate(work)

 end subroutine
!!***
