!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_scale
!! NAME
!! calc_scale
!!
!! FUNCTION
!! Compute scaling factors for Phi, tPhi and tProj
!!
!! COPYRIGHT
!! Copyright (C) 1998-2007 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  option=Option governing the normalization of Phi, tPhi and tProj
!!  pawps
!!    %phi(wav_meshsz,basis_size)= atomic partial waves
!!    %tphi(wav_meshsz,basis_size)= atomic pseudo partial waves
!!    %tproj(wav_meshsz,basis_size)= projectors on partial waves
!!  pshead
!!    %aesnl(wav_meshsz,nval)= Eigenfunctions of AE Hamiltonian
!!    %basis_size= Number of elements for the paw nl basis
!!    %orbitals(basis_size)= Quantum number l for each basis function
!!    %sph_meshsz=Dimension of radial mesh for spheres
!!    %wav_meshsz=Mesh size for partial waves and projectors inherited from uspp
!!  usdata
!!    %keyee(basis_size)= Indice of reference (eigen)energy for each basis function
!!    %lval(nval)= l angular momentum for each valence state
!!    %nval= Number of valence states
!!    %snlprj(basis_size,nval)= Projected eigentstates, i.e. <Snl(j)|Proj(i)> scalars
!!
!! OUTPUT
!!  pawarray
!!    %factscale(basis_size)= Scaling factors for Phi, tPhi and tProj
!!  pawps
!!    %phi(wav_meshsz,basis_size)= modified atomic partial waves
!!    %tphi(wav_meshsz,basis_size)= modified atomic pseudo partial waves
!!    %tproj(wav_meshsz,basis_size)= modified projectors on partial waves
!!
!! PARENTS
!!      uspp2abinit
!!
!! CHILDREN
!!
!! SOURCE

 subroutine calc_scale(option,pawarray,pawps,pawrad,pshead,usdata)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 integer :: option
 type(pawarray_type) :: pawarray
 type(pawps_type)    :: pawps
 type(pawrad_type)   :: pawrad
 type(pshead_type)   :: pshead
 type(usdata_type)   :: usdata

!Local variables ---------------------------------------
 integer :: ib,ival
 real(dp) :: intg
 real(dp),allocatable :: ff(:)

! *************************************************************************

 pawarray%factscale=one
 if (option>0) then

! Old version of scaling
  if (option==1) then
   do ib=1,pshead%basis_size
    allocate(ff(pshead%wav_meshsz))
    ff(1:pshead%wav_meshsz)=pawps%phi(1:pshead%wav_meshsz,ib)**2
    call csimp(ff,pawrad,pshead%sph_meshsz,intg)
    pawarray%factscale(ib)=dsign(1.d0/sqrt(intg),pawps%phi(pshead%wav_meshsz-2,ib))
    deallocate(ff)
   enddo
  else if (option==2) then
   do ib=1,pshead%basis_size
    pawarray%factscale(ib)=MAX(ABS(pawps%phi(pshead%sph_meshsz,ib)), &
&                              ABS(pawps%phi(pshead%sph_meshsz+1,ib)))
    pawarray%factscale(ib)=one/DSIGN(pawarray%factscale(ib),pawps%phi(pshead%sph_meshsz,ib))
   enddo
  end if
   
  do ival=1,usdata%nval
   do ib=1,pshead%basis_size
    if (usdata%lval(ival)==pshead%orbitals(ib).and.usdata%keyee(ib)==ival) &
&    pawarray%factscale(ib)=dsign(usdata%aesnl(pshead%sph_meshsz/2,ival)&
&       /pawps%phi(pshead%sph_meshsz/2,ib),pawps%phi(pshead%wav_meshsz-2,ib))
   enddo
  enddo

  do ib=1,pshead%basis_size
   pawps%phi(:,ib)=pawps%phi(:,ib)*pawarray%factscale(ib)
   pawps%tphi(:,ib)=pawps%tphi(:,ib)*pawarray%factscale(ib)
   pawps%tproj(:,ib)=pawps%tproj(:,ib)/pawarray%factscale(ib)
   do ival=1,usdata%nval
    if (usdata%lval(ival)==pshead%orbitals(ib).and.usdata%keyee(ib)==ival) &
&                       pawarray%factscale(ib)=usdata%snlprj(ib,ival)
   enddo
  enddo

 endif

 end subroutine
!!***
