!{\src2tex{textfont=tt}}
!!****f* ABINIT/calc_vhtnzc
!! NAME
!! calc_vhtnzc
!!
!! FUNCTION
!! Compute vh(tnZc) ) and the <phi_i|vh(tnZc)|phi_j> matrix elements
!! Have to descreen it
!!
!! COPYRIGHT
!! Copyright (C) 1998-2007 ABINIT group (FJ, MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  option=0 if "bare" potential is forced to zero
!!         1 if "bare" potential is computed
!!  pawarray
!!    %coreden4pr2(max_meshsz)= Core density multiplied by 4Pi.r2
!!    %rvloc0(max_meshsz)= Local (descreened) potential * r
!!    %shapefunc(wav_meshsz)= Normalized shape function
!!    %tcoreden4pr2(max_meshsz)= Pseudo core density multiplied by 4Pi.r2
!!  pawrad=datastructure containing mesh size definitions
!!  pshead
!!    %atomic_charge= Total atomic charge
!!    %max_meshsz=Maximal mesh size for densities/potentials
!!    %valence_charge= Valence charge
!!    %vbar_meshsz= Dimension of radial mesh for Vbare
!!    %vloc_meshsz= Dimension of radial mesh for vloc=vhtnzc
!!    %wav_meshsz=Mesh size for partial waves and projectors inherited from uspp
!!  un_log= Unit number for log file (comments)
!!
!! OUTPUT
!!  pawarray
!!    %vbare(wav_meshsz)= Vbare local potential used in Blochl/Holzwarth's formulation
!!  pawps
!!    %vhtnzc(max_meshsz)= Hartree potential of the ps-density
!!                         of the nucleus + core electrons
!!
!! NOTES
!! When writing Vbare (in wrpawps), do not forget to write it up to RcLoc !
!!
!! PARENTS
!!      uspp2abinit
!!
!! CHILDREN
!!      csimp,deducer0,poisson
!!
!! SOURCE

 subroutine calc_vhtnzc(pawarray,pawrad,pawps,pshead,option,un_log)


  use defs_basis
  use defs_pawps

  implicit none

!Arguments ---------------------------------------------
 integer :: option,un_log
 type(pawarray_type) :: pawarray
 type(pawrad_type)   :: pawrad
 type(pawps_type)    :: pawps
 type(pshead_type)   :: pshead

!Local variables ---------------------------------------
 integer :: meshsz,maxmsz,vbrmsz
 real(dp) :: qcore
 real(dp),allocatable :: den(:),ff(:),rvbare(:),rvhtnzc1(:)
!--------------------------------------------------------

 meshsz=pshead%wav_meshsz
 maxmsz=pshead%max_meshsz

!Compute Qcore
 allocate(ff(pshead%max_meshsz));ff(:)=pawarray%coreden4pr2(:)-pawarray%tcoreden4pr2(:)
 call csimp(ff,pawrad,pshead%max_meshsz,qcore)
 deallocate(ff)

 allocate(rvbare(maxmsz),rvhtnzc1(maxmsz))

!Compute r*Vh(tnZC) with Poisson equation and vbare=0
!----------------------------------------------------
 allocate(den(maxmsz))
 den(1:maxmsz)=pawarray%tcoreden4pr2(1:maxmsz)
 den(1:meshsz)=den(1:meshsz)+(qcore-pshead%atomic_charge)*pawarray%shapefunc(1:meshsz)*pawrad%rad(1:meshsz)**2
 call poisson(den,maxmsz,pawrad,rvhtnzc1)
 deallocate(den)

!Compute vbare inside sphere by difference
!-----------------------------------------
!Eventually impose vbare=0 inside sphere (for test purpose only)
 if (option==0) then
  rvbare=zero
 else
  rvbare(:)=pawarray%rvloc0(:)-rvhtnzc1(:)
 endif

!Compute Vh(tnZC) everywhere, imposing vbare=0 outside sphere
!--------------------------------------------------------------
 vbrmsz=max(meshsz,pshead%vbar_meshsz)
 pawps%vhtnzc(:)=rvhtnzc1(:)
 pawps%vhtnzc(1:vbrmsz)=pawps%vhtnzc(1:vbrmsz)+rvbare(1:vbrmsz)
 pawps%vhtnzc(2:maxmsz)=pawps%vhtnzc(2:maxmsz)/pawrad%rad(2:maxmsz)
 call deducer0(pawps%vhtnzc,pawrad)

 deallocate(rvbare,rvhtnzc1)

!Test the behaviour of VhtnZc at long range: vhtnzc(r)=-Z/r ?
!-----------------------------------------------------------
  write(un_log,'(/,a)') '> USpp->Abinit translator INFO:'
  write(un_log,'(a,f5.2,a,a,es11.4)') &
&   '  At r_vloc=',pawrad%rad(pshead%vloc_meshsz),' a.u.,',&
&   ' VHartree(ntild(Zv+Zc))= -Zv/r + ',&
&     pawps%vhtnzc(pshead%vloc_meshsz) &
&    +pshead%valence_charge/pawrad%rad(pshead%vloc_meshsz)
  write(un_log,'(a)') &
&   '  This quantity must be as small as possible.'

 end subroutine calc_vhtnzc

!!***
