!{\src2tex{textfont=tt}}
!!****f* ABINIT/nderiv
!! NAME
!! nderiv
!!
!! FUNCTION
!! Given an input function y(x) on a logarithmic grid,
!! compute its first derivative
!!
!! COPYRIGHT
!! Copyright (C) 1998-2007 ABINIT group (FJ,MT)
!! This file is distributed under the terms of the
!! GNU General Public License, see ~ABINIT/Infos/copyright
!! or http://www.gnu.org/copyleft/gpl.txt .
!! For the initials of contributors, see ~ABINIT/Infos/contributors .
!!
!! INPUTS
!!  ndim= radial mesh size
!!  step= Logarithmic step corresponding to radial mesh
!!  radfact(ndim)= Factor used to compute radial integrals on generalized grid
!!  y(ndim)= input function
!!
!! OUTPUT
!!  z(ndim)= first derivative of y
!!
!! PARENTS
!!  calc_kij
!!
!! CHILDREN
!!
!! SOURCE

 subroutine nderiv(ndim,step,radfact,y,z)

 use defs_basis
 use defs_pawps

 implicit none

!Arguments ---------------------------------------------
 integer :: ndim
 real(dp) :: step
 real(dp) :: radfact(ndim),y(ndim),z(ndim)

!Local variables ---------------------------------------
 integer :: i
 real(dp) :: a,b,c,hh,yy

! *********************************************************************

!Prepare differentiation loop
 hh=1.d0/(12.d0*step)
 yy=y(ndim-4)
 b=hh*(-25.d0*y(1)+48.d0*y(2)-36.d0*y(3)+16.d0*y(4)-3.d0*y(5))
 c=hh*(-3.d0*y(1)-10.d0*y(2)+18.d0*y(3)-6.d0*y(4)+y(5))

!Start differentiation loop
 do i=5,ndim
  a=b;b=c
  c=hh*(y(i-4)-y(i)+8.d0*(y(i-1)-y(i-3)))
  z(i-4)=a
 enddo

!Normal exit
 a=hh*(-yy+6.d0*y(ndim-3)-18.d0*y(ndim-2)+10.d0*y(ndim-1)+3.d0*y(ndim))
 z(ndim)=hh*(3.d0*yy-16.d0*y(ndim-3)+36.d0*y(ndim-2)-48.d0*y(ndim-1)+25.d0*y(ndim))
 z(ndim-1)=a
 z(ndim-2)=c
 z(ndim-3)=b

!Convert back to logarithmic mesh
 z(1:ndim)=z(1:ndim)/radfact(1:ndim)

 end subroutine
!!***
